import { Injectable, Directive, NgModule } from '@angular/core';
import { HttpHeaders, HttpClient, HttpClientModule } from '@angular/common/http';
import { Subject, of } from 'rxjs';
import { catchError } from 'rxjs/operators';
import { BrowserModule } from '@angular/platform-browser';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ComService {
    constructor() {
        // Observable string sources
        this.secretDirectlineToken = new Subject();
        this.styleSetPayload = new Subject();
        this.styleOptionsPayload = new Subject();
        // Observable string streams
        this.secretToken$ = this.secretDirectlineToken.asObservable();
        this.styleSet$ = this.styleSetPayload.asObservable();
        this.styleOptions$ = this.styleOptionsPayload.asObservable();
    }
    // Service message commands
    /**
     * @param {?} payload
     * @return {?}
     */
    obtainToken(payload) {
        this.secretDirectlineToken.next(payload);
    }
    /**
     * @param {?=} styleoptionsPayload
     * @param {?=} stylesetPayload
     * @return {?}
     */
    obtainStylePayload(styleoptionsPayload, stylesetPayload) {
        this.styleSetPayload.next(stylesetPayload);
        this.styleOptionsPayload.next(styleoptionsPayload);
    }
}
ComService.decorators = [
    { type: Injectable }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class MessageService {
    constructor() {
        this.messages = [];
    }
    /**
     * @param {?} message
     * @return {?}
     */
    add(message) {
        this.messages.push(message);
    }
    /**
     * @return {?}
     */
    clear() {
        this.messages = [];
    }
}
MessageService.decorators = [
    { type: Injectable }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Handles HttpClient errors
 */
class HttpErrorHandler {
    /**
     * @param {?} messageService
     */
    constructor(messageService) {
        this.messageService = messageService;
        /**
         * Create curried handleError function that already knows the service name
         */
        this.createHandleError = (/**
         * @param {?=} serviceName
         * @return {?}
         */
        (serviceName = '') => (/**
         * @template T
         * @param {?=} operation
         * @param {?=} result
         * @return {?}
         */
        (operation = 'operation', result = (/** @type {?} */ ({}))) => this.handleError(serviceName, operation, result)));
    }
    /**
     * Returns a function that handles Http operation failures.
     * This error handler lets the app continue to run as if no error occurred.
     * @template T
     * @param {?=} serviceName = name of the data service that attempted the operation
     * @param {?=} operation - name of the operation that failed
     * @param {?=} result - optional value to return as the observable result
     * @return {?}
     */
    handleError(serviceName = '', operation = 'operation', result = (/** @type {?} */ ({}))) {
        return (/**
         * @param {?} error
         * @return {?}
         */
        (error) => {
            // TODO: send the error to remote logging infrastructure
            console.error(error, operation); // log to console instead and add specific service call
            // log to console instead and add specific service call
            /** @type {?} */
            const message = (error.error instanceof ErrorEvent) ?
                error.error.message :
                `server returned code ${error.status} with body "${error.error}"`;
            // TODO: better job of transforming error for user consumption
            this.messageService.add(`${serviceName}: ${operation} failed: ${message}`);
            // Let the app keep running by returning a safe result.
            return of(result);
        });
    }
}
HttpErrorHandler.decorators = [
    { type: Injectable }
];
/** @nocollapse */
HttpErrorHandler.ctorParameters = () => [
    { type: MessageService }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const httpOptions = {
    headers: new HttpHeaders({
        'Content-Type': 'application/json',
        'Authorization': 'my-auth-token'
    })
};
class AppService {
    /**
     * @param {?} http
     * @param {?} comService
     * @param {?} httpErrorHandler
     */
    constructor(http, comService, httpErrorHandler) {
        this.http = http;
        this.comService = comService;
        this.handleError = httpErrorHandler.createHandleError('AppService');
        this.subscription = comService.secretToken$.subscribe((/**
         * @param {?} response
         * @return {?}
         */
        response => {
            this.botTokenHeader =
                httpOptions.headers.set('Authorization', 'BotConnector ' + response.secret);
            this.webchatUrl = response.url;
            this.secretSetting = response.secretSetting;
        }));
    }
    /**
     * GET temporary token from the server api
     * @return {?}
     */
    getTokenObs() {
        if (this.secretSetting) {
            return this.http.get(this.webchatUrl, { headers: this.botTokenHeader, observe: 'response' })
                .pipe(catchError(this.handleError('getTokenObs', [])));
        }
        else {
            return of(false);
        }
    }
    /**
     * @return {?}
     */
    makeIntentionalError() {
        return this.http.get('not/a/real/url')
            .pipe(catchError(this.handleError('makeIntentionalError', [])));
    }
}
AppService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
AppService.ctorParameters = () => [
    { type: HttpClient },
    { type: ComService },
    { type: HttpErrorHandler }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class StyleSetDirective {
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    Activities(a, b) {
        return a = Object.assign({}, a, b);
    }
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    Activity(a, b) {
        return a = Object.assign({}, a, b);
    }
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    AudioAttachment(a, b) {
        return a = Object.assign({}, a, b);
    }
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    AudioContent(a, b) {
        return a = Object.assign({}, a, b);
    }
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    Avatar(a, b) {
        return a = Object.assign({}, a, b);
    }
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    Bubble(a, b) {
        return a = Object.assign({}, a, b);
    }
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    CarouselFilmStrip(a, b) {
        return a = Object.assign({}, a, b);
    }
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    CarouselFlipper(a, b) {
        return a = Object.assign({}, a, b);
    }
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    ConnectivityNotification(a, b) {
        return a = Object.assign({}, a, b);
    }
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    DictationInterims(a, b) {
        return a = Object.assign({}, a, b);
    }
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    DownloadAttachment(a, b) {
        return a = Object.assign({}, a, b);
    }
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    ErrorBox(a, b) {
        return a = Object.assign({}, a, b);
    }
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    ErrorNotification(a, b) {
        return a = Object.assign({}, a, b);
    }
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    MicrophoneButton(a, b) {
        return a = Object.assign({}, a, b);
    }
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    Root(a, b) {
        return a = Object.assign({}, a, b);
    }
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    ScrollToEndButton(a, b) {
        return a = Object.assign({}, a, b);
    }
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    SendBox(a, b) {
        return a = Object.assign({}, a, b);
    }
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    SendBoxButton(a, b) {
        return a = Object.assign({}, a, b);
    }
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    SendBoxTextArea(a, b) {
        return a = Object.assign({}, a, b);
    }
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    SendBoxTextBox(a, b) {
        return a = Object.assign({}, a, b);
    }
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    SendStatus(a, b) {
        return a = Object.assign({}, a, b);
    }
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    SingleAttachmentActivity(a, b) {
        return a = Object.assign({}, a, b);
    }
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    SpinnerAnimation(a, b) {
        return a = Object.assign({}, a, b);
    }
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    StackedLayout(a, b) {
        return a = Object.assign({}, a, b);
    }
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    SuggestedAction(a, b) {
        return a = Object.assign({}, a, b);
    }
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    SuggestedActions(a, b) {
        return a = Object.assign({}, a, b);
    }
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    SuggestedActionsStyleSet(a, b) {
        return a = Object.assign({}, a, b);
    }
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    TextContent(a, b) {
        return a = Object.assign({}, a, b);
    }
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    Timestamp(a, b) {
        return a = Object.assign({}, a, b);
    }
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    TypingActivity(a, b) {
        return a = Object.assign({}, a, b);
    }
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    TypingAnimation(a, b) {
        return a = Object.assign({}, a, b);
    }
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    UploadButton(a, b) {
        return a = Object.assign({}, a, b);
    }
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    VideoAttachment(a, b) {
        return a = Object.assign({}, a, b);
    }
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    VideoContent(a, b) {
        return a = Object.assign({}, a, b);
    }
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    VimeoContent(a, b) {
        return a = Object.assign({}, a, b);
    }
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    WarningNotification(a, b) {
        return a = Object.assign({}, a, b);
    }
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    YouTubeContent(a, b) {
        return a = Object.assign({}, a, b);
    }
}
StyleSetDirective.decorators = [
    { type: Directive, args: [{
                selector: 'app-style-set',
                providers: [AppService, ComService]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
window.WebChat = window.WebChat || {};
class BotDirective {
    /**
     * @param {?} styleSetDir
     * @param {?} http
     * @param {?} appService
     * @param {?} comService
     */
    constructor(styleSetDir, http, appService, comService) {
        this.styleSetDir = styleSetDir;
        this.http = http;
        this.appService = appService;
        this.comService = comService;
        comService.secretToken$.subscribe((/**
         * @param {?} secret
         * @return {?}
         */
        secret => {
            this.secretSetting = secret.secretSetting;
            this.secret = secret.secret;
        }));
        comService.styleSet$.subscribe((/**
         * @param {?} response
         * @return {?}
         */
        response => {
            if (response != null || response != undefined) {
                // styleset set to property options for creatstyleset set from user
                this.styleSet = window.WebChat.createStyleSet(response);
                // stylesetdirective properties set to response from user
                this.styleSetDir.activities = response.activties;
                this.styleSetDir.activity = response.activity;
                this.styleSetDir.audioAttachment = response.audioAttachment;
                this.styleSetDir.audioContent = response.audioContent;
                this.styleSetDir.avatar = response.avatar;
                this.styleSetDir.bubble = response.bubble;
                this.styleSetDir.carouselFilmStrip = response.carouselFilmStrip;
                this.styleSetDir.carouselFlipper = response.carouselFlipper;
                this.styleSetDir.connectivityNotification = response.connectivityNotification;
                this.styleSetDir.dictationInterims = response.dictationInterims;
                this.styleSetDir.downloadAttachment = response.downloadAttachment;
                this.styleSetDir.errorBox = response.errorBox;
                this.styleSetDir.errorNotification = response.errorNotification;
                this.styleSetDir.microphoneButton = response.microphoneButton;
                this.styleSetDir.root = response.root;
                this.styleSetDir.scrollToEndButton = response.scrollToEndButton;
                this.styleSetDir.sendBox = response.sendBox;
                this.styleSetDir.sendBoxButton = response.sendBoxButton;
                this.styleSetDir.sendBoxTextArea = response.sendBoxTextArea;
                this.styleSetDir.sendBoxTextBox = response.sendBoxTextBox;
                this.styleSetDir.sendStatus = response.sendStatus;
                this.styleSetDir.singleAttachmentActivity = response.singleAttachmentActivity;
                this.styleSetDir.spinnerAnnimation = response.spinnerAnnimation;
                this.styleSetDir.stackedLayout = response.stackedLayout;
                this.styleSetDir.suggestedAction = response.suggestedAction;
                this.styleSetDir.suggestedActionsStyleSet = response.suggestedActionsStyleSet;
                this.styleSetDir.textContent = response.textContent;
                this.styleSetDir.timestamp = response.timestamp;
                this.styleSetDir.typingActivity = response.typingActivity;
                this.styleSetDir.uploadButton = response.uploadButton;
                this.styleSetDir.videoAttachment = response.videoAttachment;
                this.styleSetDir.videoContent = response.videoContent;
                this.styleSetDir.vimeoContent = response.vimeoContent;
                this.styleSetDir.warningNotification = response.warningNotification;
                this.styleSetDir.youTubeContent = response.youTubContent;
            }
        }));
        comService.styleOptions$.subscribe((/**
         * @param {?} response
         * @return {?}
         */
        response => {
            if (response !== null || response !== undefined) {
                this.styleOptions = response;
            }
        }));
    }
    /**
     * @param {?} viewChild
     * @return {?}
     */
    botDirective(viewChild) {
        this.viewChild = viewChild;
        /** @type {?} */
        let token;
        this.appService.getTokenObs()
            .subscribe((/**
         * @param {?} response
         * @return {?}
         */
        response => {
            this.secretSetting ? token = response.body : token = this.secret;
            if (response.status == 200 && response.statusText == 'OK' || response == false) {
                /** @type {?} */
                const directLine = window.WebChat.createDirectLine({
                    secret: token,
                    webSocket: false
                });
                if (this.styleSet && this.styleOptions) {
                    window.WebChat.renderWebChat({
                        directLine: directLine,
                        userID: "USER_ID",
                        styleOptions: this.styleOptions,
                        styleSet: this.styleSet
                    }, this.viewChild);
                }
                else if (this.styleSet && !this.styleOptions) {
                    window.WebChat.renderWebChat({
                        directLine: directLine,
                        userID: "USER_ID",
                        styleSet: this.styleSet
                    }, this.viewChild);
                }
                else if (this.styleOptions && !this.styleSet) {
                    window.WebChat.renderWebChat({
                        directLine: directLine,
                        userID: "USER_ID",
                        styleOptions: this.styleOptions,
                    }, this.viewChild);
                }
                else {
                    window.WebChat.renderWebChat({
                        directLine: directLine,
                        userID: "USER_ID",
                    }, this.viewChild);
                }
                directLine
                    .postActivity({
                    from: { id: "USER_ID", name: "USER_NAME" },
                    name: "requestWelcomeDialog",
                    type: "event",
                    value: "token"
                })
                    .subscribe((/**
                 * @param {?} id
                 * @return {?}
                 */
                id => console.log(`Posted activity, assigned ID ${id}`)), (/**
                 * @param {?} error
                 * @return {?}
                 */
                error => console.log(`Error posting activity ${error}`)));
            }
            if (this.styleSet != null || this.styleSet != undefined) {
                this.styleSet.activities = this.styleSetDir.Activities(this.styleSet.activities, this.styleSetDir.activities);
                this.styleSet.activity = this.styleSetDir.Activity(this.styleSet.activity, this.styleSetDir.activity);
                this.styleSet.audioAttachment = this.styleSetDir.AudioAttachment(this.styleSet.audioAttachment, this.styleSetDir.audioAttachment);
                this.styleSet.audioContent = this.styleSetDir.AudioContent(this.styleSet.audioContent, this.styleSetDir.audioContent);
                this.styleSet.avatar = this.styleSetDir.Avatar(this.styleSet.avatar, this.styleSetDir.avatar);
                this.styleSet.bubble = this.styleSetDir.Bubble(this.styleSet.bubble, this.styleSetDir.bubble);
                this.styleSet.carouselFilmStrip = this.styleSetDir.CarouselFilmStrip(this.styleSet.carouselFilmStrip, this.styleSetDir.carouselFilmStrip);
                this.styleSet.carouselFlipper = this.styleSetDir.CarouselFlipper(this.styleSet.carouselFlipper, this.styleSetDir.carouselFlipper);
                this.styleSet.connectivityNotification = this.styleSetDir.ConnectivityNotification(this.styleSet.connectivityNotification, this.styleSetDir.connectivityNotification);
                this.styleSet.dictationInterims = this.styleSetDir.DictationInterims(this.styleSet.dictationInterims, this.styleSetDir.dictationInterims);
                this.styleSet.downloadAttachment = this.styleSetDir.DownloadAttachment(this.styleSet.downloadAttachment, this.styleSetDir.downloadAttachment);
                this.styleSet.errorBox = this.styleSetDir.ErrorBox(this.styleSet.errorBox, this.styleSetDir.errorBox);
                this.styleSet.errorNotification = this.styleSetDir.ErrorNotification(this.styleSet.errorNotification, this.styleSetDir.errorNotification);
                this.styleSet.microphoneButton = this.styleSetDir.MicrophoneButton(this.styleSet.microphoneButton, this.styleSetDir.microphoneButton);
                this.styleSet.root = this.styleSetDir.Root(this.styleSet.root, this.styleSetDir.root);
                this.styleSet.scrollToEndButton = this.styleSetDir.ScrollToEndButton(this.styleSet.scrollToEndButton, this.styleSetDir.scrollToEndButton);
                this.styleSet.sendBox = this.styleSetDir.SendBox(this.styleSet.sendBox, this.styleSetDir.sendBox);
                this.styleSet.sendBoxButton = this.styleSetDir.SendBoxButton(this.styleSet.sendBoxButton, this.styleSetDir.sendBoxButton);
                this.styleSet.sendBoxTextArea = this.styleSetDir.SendBoxTextArea(this.styleSet.sendBoxTextArea, this.styleSetDir.sendBoxTextArea);
                this.styleSet.sendBoxTextBox = this.styleSetDir.SendBoxTextBox(this.styleSet.sendBoxTextBox, this.styleSetDir.sendBoxTextBox);
                this.styleSet.sendStatus = this.styleSetDir.SendStatus(this.styleSet.sendStatus, this.styleSetDir.sendStatus);
                this.styleSet.singleAttachmentActivity = this.styleSetDir.SingleAttachmentActivity(this.styleSet.singleAttachmentActivity, this.styleSetDir.singleAttachmentActivity);
                this.styleSet.spinnerAnnimation = this.styleSetDir.SpinnerAnimation(this.styleSet.spinnerAnnimation, this.styleSetDir.spinnerAnnimation);
                this.styleSet.stackedLayout = this.styleSetDir.StackedLayout(this.styleSet.stackedLayout, this.styleSetDir.stackedLayout);
                this.styleSet.suggestedAction = this.styleSetDir.SuggestedAction(this.styleSet.suggestedAction, this.styleSetDir.suggestedAction);
                this.styleSet.suggestedActionsStyleSet = this.styleSetDir.SuggestedActionsStyleSet(this.styleSet.suggestedActionsStyleSet, this.styleSetDir.suggestedActionsStyleSet);
                this.styleSet.textContent = this.styleSetDir.TextContent(this.styleSet.textContent, this.styleSetDir.textContent);
                this.styleSet.timestamp = this.styleSetDir.Timestamp(this.styleSet.timestamp, this.styleSetDir.timestamp);
                this.styleSet.typingActivity = this.styleSetDir.TypingActivity(this.styleSet.typingActivity, this.styleSetDir.typingActivity);
                this.styleSet.typingAnimation = this.styleSetDir.TypingAnimation(this.styleSet.typingAnimation, this.styleSetDir.typingAnimation);
                this.styleSet.uploadButton = this.styleSetDir.UploadButton(this.styleSet.uploadButton, this.styleSetDir.uploadButton);
                this.styleSet.videoAttachment = this.styleSetDir.VideoAttachment(this.styleSet.videoAttachment, this.styleSetDir.videoAttachment);
                this.styleSet.videoContent = this.styleSetDir.VideoContent(this.styleSet.videoContent, this.styleSetDir.videoContent);
                this.styleSet.vimeoContent = this.styleSetDir.VimeoContent(this.styleSet.vimeoContent, this.styleSetDir.vimeoContent);
                this.styleSet.warningNotification = this.styleSetDir.WarningNotification(this.styleSet.warningNotification, this.styleSetDir.warningNotification);
                this.styleSet.youTubeContent = this.styleSetDir.YouTubeContent(this.styleSet.youTubeContent, this.styleSetDir.youTubeContent);
            }
        }));
    }
    /**
     * @return {?}
     */
    makeError() {
        this.appService.makeIntentionalError().subscribe(null, (/**
         * @param {?} error
         * @return {?}
         */
        error => this.error = error));
    }
}
BotDirective.decorators = [
    { type: Directive, args: [{
                selector: 'app-bot',
                providers: [AppService, ComService]
            },] }
];
/** @nocollapse */
BotDirective.ctorParameters = () => [
    { type: StyleSetDirective },
    { type: HttpClient },
    { type: AppService },
    { type: ComService }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NgxMicrosoftBotFrameworkModule {
}
NgxMicrosoftBotFrameworkModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    BotDirective,
                    StyleSetDirective,
                ],
                imports: [
                    BrowserModule,
                    HttpClientModule,
                ],
                exports: [],
                providers: [
                    HttpErrorHandler,
                    MessageService,
                ]
            },] }
];

export { AppService, BotDirective, ComService, HttpErrorHandler, MessageService, NgxMicrosoftBotFrameworkModule, StyleSetDirective };
//# sourceMappingURL=ngx-microsoft-bot-framework.js.map
