import { Injectable, Directive, NgModule } from '@angular/core';
import { HttpHeaders, HttpClient, HttpClientModule } from '@angular/common/http';
import { Subject, of } from 'rxjs';
import { catchError } from 'rxjs/operators';
import { BrowserModule } from '@angular/platform-browser';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var ComService = /** @class */ (function () {
    function ComService() {
        // Observable string sources
        this.secretDirectlineToken = new Subject();
        this.styleSetPayload = new Subject();
        this.styleOptionsPayload = new Subject();
        // Observable string streams
        this.secretToken$ = this.secretDirectlineToken.asObservable();
        this.styleSet$ = this.styleSetPayload.asObservable();
        this.styleOptions$ = this.styleOptionsPayload.asObservable();
    }
    // Service message commands
    // Service message commands
    /**
     * @param {?} payload
     * @return {?}
     */
    ComService.prototype.obtainToken = 
    // Service message commands
    /**
     * @param {?} payload
     * @return {?}
     */
    function (payload) {
        this.secretDirectlineToken.next(payload);
    };
    /**
     * @param {?=} styleoptionsPayload
     * @param {?=} stylesetPayload
     * @return {?}
     */
    ComService.prototype.obtainStylePayload = /**
     * @param {?=} styleoptionsPayload
     * @param {?=} stylesetPayload
     * @return {?}
     */
    function (styleoptionsPayload, stylesetPayload) {
        this.styleSetPayload.next(stylesetPayload);
        this.styleOptionsPayload.next(styleoptionsPayload);
    };
    ComService.decorators = [
        { type: Injectable }
    ];
    return ComService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var MessageService = /** @class */ (function () {
    function MessageService() {
        this.messages = [];
    }
    /**
     * @param {?} message
     * @return {?}
     */
    MessageService.prototype.add = /**
     * @param {?} message
     * @return {?}
     */
    function (message) {
        this.messages.push(message);
    };
    /**
     * @return {?}
     */
    MessageService.prototype.clear = /**
     * @return {?}
     */
    function () {
        this.messages = [];
    };
    MessageService.decorators = [
        { type: Injectable }
    ];
    return MessageService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Handles HttpClient errors
 */
var HttpErrorHandler = /** @class */ (function () {
    function HttpErrorHandler(messageService) {
        var _this = this;
        this.messageService = messageService;
        /**
         * Create curried handleError function that already knows the service name
         */
        this.createHandleError = (/**
         * @param {?=} serviceName
         * @return {?}
         */
        function (serviceName) {
            if (serviceName === void 0) { serviceName = ''; }
            return (/**
             * @template T
             * @param {?=} operation
             * @param {?=} result
             * @return {?}
             */
            function (operation, result) {
                if (operation === void 0) { operation = 'operation'; }
                if (result === void 0) { result = (/** @type {?} */ ({})); }
                return _this.handleError(serviceName, operation, result);
            });
        });
    }
    /**
     * Returns a function that handles Http operation failures.
     * This error handler lets the app continue to run as if no error occurred.
     * @param serviceName = name of the data service that attempted the operation
     * @param operation - name of the operation that failed
     * @param result - optional value to return as the observable result
     */
    /**
     * Returns a function that handles Http operation failures.
     * This error handler lets the app continue to run as if no error occurred.
     * @template T
     * @param {?=} serviceName = name of the data service that attempted the operation
     * @param {?=} operation - name of the operation that failed
     * @param {?=} result - optional value to return as the observable result
     * @return {?}
     */
    HttpErrorHandler.prototype.handleError = /**
     * Returns a function that handles Http operation failures.
     * This error handler lets the app continue to run as if no error occurred.
     * @template T
     * @param {?=} serviceName = name of the data service that attempted the operation
     * @param {?=} operation - name of the operation that failed
     * @param {?=} result - optional value to return as the observable result
     * @return {?}
     */
    function (serviceName, operation, result) {
        var _this = this;
        if (serviceName === void 0) { serviceName = ''; }
        if (operation === void 0) { operation = 'operation'; }
        if (result === void 0) { result = (/** @type {?} */ ({})); }
        return (/**
         * @param {?} error
         * @return {?}
         */
        function (error) {
            // TODO: send the error to remote logging infrastructure
            console.error(error, operation); // log to console instead and add specific service call
            // log to console instead and add specific service call
            /** @type {?} */
            var message = (error.error instanceof ErrorEvent) ?
                error.error.message :
                "server returned code " + error.status + " with body \"" + error.error + "\"";
            // TODO: better job of transforming error for user consumption
            _this.messageService.add(serviceName + ": " + operation + " failed: " + message);
            // Let the app keep running by returning a safe result.
            return of(result);
        });
    };
    HttpErrorHandler.decorators = [
        { type: Injectable }
    ];
    /** @nocollapse */
    HttpErrorHandler.ctorParameters = function () { return [
        { type: MessageService }
    ]; };
    return HttpErrorHandler;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
var httpOptions = {
    headers: new HttpHeaders({
        'Content-Type': 'application/json',
        'Authorization': 'my-auth-token'
    })
};
var AppService = /** @class */ (function () {
    function AppService(http, comService, httpErrorHandler) {
        var _this = this;
        this.http = http;
        this.comService = comService;
        this.handleError = httpErrorHandler.createHandleError('AppService');
        this.subscription = comService.secretToken$.subscribe((/**
         * @param {?} response
         * @return {?}
         */
        function (response) {
            _this.botTokenHeader =
                httpOptions.headers.set('Authorization', 'BotConnector ' + response.secret);
            _this.webchatUrl = response.url;
            _this.secretSetting = response.secretSetting;
        }));
    }
    /** GET temporary token from the server api */
    /**
     * GET temporary token from the server api
     * @return {?}
     */
    AppService.prototype.getTokenObs = /**
     * GET temporary token from the server api
     * @return {?}
     */
    function () {
        if (this.secretSetting) {
            return this.http.get(this.webchatUrl, { headers: this.botTokenHeader, observe: 'response' })
                .pipe(catchError(this.handleError('getTokenObs', [])));
        }
        else {
            return of(false);
        }
    };
    /**
     * @return {?}
     */
    AppService.prototype.makeIntentionalError = /**
     * @return {?}
     */
    function () {
        return this.http.get('not/a/real/url')
            .pipe(catchError(this.handleError('makeIntentionalError', [])));
    };
    AppService.decorators = [
        { type: Injectable }
    ];
    /** @nocollapse */
    AppService.ctorParameters = function () { return [
        { type: HttpClient },
        { type: ComService },
        { type: HttpErrorHandler }
    ]; };
    return AppService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var StyleSetDirective = /** @class */ (function () {
    function StyleSetDirective() {
    }
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    StyleSetDirective.prototype.Activities = /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    function (a, b) {
        return a = Object.assign({}, a, b);
    };
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    StyleSetDirective.prototype.Activity = /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    function (a, b) {
        return a = Object.assign({}, a, b);
    };
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    StyleSetDirective.prototype.AudioAttachment = /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    function (a, b) {
        return a = Object.assign({}, a, b);
    };
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    StyleSetDirective.prototype.AudioContent = /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    function (a, b) {
        return a = Object.assign({}, a, b);
    };
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    StyleSetDirective.prototype.Avatar = /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    function (a, b) {
        return a = Object.assign({}, a, b);
    };
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    StyleSetDirective.prototype.Bubble = /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    function (a, b) {
        return a = Object.assign({}, a, b);
    };
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    StyleSetDirective.prototype.CarouselFilmStrip = /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    function (a, b) {
        return a = Object.assign({}, a, b);
    };
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    StyleSetDirective.prototype.CarouselFlipper = /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    function (a, b) {
        return a = Object.assign({}, a, b);
    };
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    StyleSetDirective.prototype.ConnectivityNotification = /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    function (a, b) {
        return a = Object.assign({}, a, b);
    };
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    StyleSetDirective.prototype.DictationInterims = /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    function (a, b) {
        return a = Object.assign({}, a, b);
    };
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    StyleSetDirective.prototype.DownloadAttachment = /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    function (a, b) {
        return a = Object.assign({}, a, b);
    };
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    StyleSetDirective.prototype.ErrorBox = /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    function (a, b) {
        return a = Object.assign({}, a, b);
    };
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    StyleSetDirective.prototype.ErrorNotification = /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    function (a, b) {
        return a = Object.assign({}, a, b);
    };
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    StyleSetDirective.prototype.MicrophoneButton = /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    function (a, b) {
        return a = Object.assign({}, a, b);
    };
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    StyleSetDirective.prototype.Root = /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    function (a, b) {
        return a = Object.assign({}, a, b);
    };
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    StyleSetDirective.prototype.ScrollToEndButton = /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    function (a, b) {
        return a = Object.assign({}, a, b);
    };
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    StyleSetDirective.prototype.SendBox = /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    function (a, b) {
        return a = Object.assign({}, a, b);
    };
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    StyleSetDirective.prototype.SendBoxButton = /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    function (a, b) {
        return a = Object.assign({}, a, b);
    };
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    StyleSetDirective.prototype.SendBoxTextArea = /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    function (a, b) {
        return a = Object.assign({}, a, b);
    };
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    StyleSetDirective.prototype.SendBoxTextBox = /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    function (a, b) {
        return a = Object.assign({}, a, b);
    };
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    StyleSetDirective.prototype.SendStatus = /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    function (a, b) {
        return a = Object.assign({}, a, b);
    };
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    StyleSetDirective.prototype.SingleAttachmentActivity = /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    function (a, b) {
        return a = Object.assign({}, a, b);
    };
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    StyleSetDirective.prototype.SpinnerAnimation = /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    function (a, b) {
        return a = Object.assign({}, a, b);
    };
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    StyleSetDirective.prototype.StackedLayout = /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    function (a, b) {
        return a = Object.assign({}, a, b);
    };
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    StyleSetDirective.prototype.SuggestedAction = /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    function (a, b) {
        return a = Object.assign({}, a, b);
    };
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    StyleSetDirective.prototype.SuggestedActions = /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    function (a, b) {
        return a = Object.assign({}, a, b);
    };
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    StyleSetDirective.prototype.SuggestedActionsStyleSet = /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    function (a, b) {
        return a = Object.assign({}, a, b);
    };
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    StyleSetDirective.prototype.TextContent = /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    function (a, b) {
        return a = Object.assign({}, a, b);
    };
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    StyleSetDirective.prototype.Timestamp = /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    function (a, b) {
        return a = Object.assign({}, a, b);
    };
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    StyleSetDirective.prototype.TypingActivity = /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    function (a, b) {
        return a = Object.assign({}, a, b);
    };
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    StyleSetDirective.prototype.TypingAnimation = /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    function (a, b) {
        return a = Object.assign({}, a, b);
    };
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    StyleSetDirective.prototype.UploadButton = /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    function (a, b) {
        return a = Object.assign({}, a, b);
    };
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    StyleSetDirective.prototype.VideoAttachment = /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    function (a, b) {
        return a = Object.assign({}, a, b);
    };
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    StyleSetDirective.prototype.VideoContent = /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    function (a, b) {
        return a = Object.assign({}, a, b);
    };
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    StyleSetDirective.prototype.VimeoContent = /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    function (a, b) {
        return a = Object.assign({}, a, b);
    };
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    StyleSetDirective.prototype.WarningNotification = /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    function (a, b) {
        return a = Object.assign({}, a, b);
    };
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    StyleSetDirective.prototype.YouTubeContent = /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    function (a, b) {
        return a = Object.assign({}, a, b);
    };
    StyleSetDirective.decorators = [
        { type: Directive, args: [{
                    selector: 'app-style-set',
                    providers: [AppService, ComService]
                },] }
    ];
    return StyleSetDirective;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
window.WebChat = window.WebChat || {};
var BotDirective = /** @class */ (function () {
    function BotDirective(styleSetDir, http, appService, comService) {
        var _this = this;
        this.styleSetDir = styleSetDir;
        this.http = http;
        this.appService = appService;
        this.comService = comService;
        comService.secretToken$.subscribe((/**
         * @param {?} secret
         * @return {?}
         */
        function (secret) {
            _this.secretSetting = secret.secretSetting;
            _this.secret = secret.secret;
        }));
        comService.styleSet$.subscribe((/**
         * @param {?} response
         * @return {?}
         */
        function (response) {
            if (response != null || response != undefined) {
                // styleset set to property options for creatstyleset set from user
                _this.styleSet = window.WebChat.createStyleSet(response);
                // stylesetdirective properties set to response from user
                _this.styleSetDir.activities = response.activties;
                _this.styleSetDir.activity = response.activity;
                _this.styleSetDir.audioAttachment = response.audioAttachment;
                _this.styleSetDir.audioContent = response.audioContent;
                _this.styleSetDir.avatar = response.avatar;
                _this.styleSetDir.bubble = response.bubble;
                _this.styleSetDir.carouselFilmStrip = response.carouselFilmStrip;
                _this.styleSetDir.carouselFlipper = response.carouselFlipper;
                _this.styleSetDir.connectivityNotification = response.connectivityNotification;
                _this.styleSetDir.dictationInterims = response.dictationInterims;
                _this.styleSetDir.downloadAttachment = response.downloadAttachment;
                _this.styleSetDir.errorBox = response.errorBox;
                _this.styleSetDir.errorNotification = response.errorNotification;
                _this.styleSetDir.microphoneButton = response.microphoneButton;
                _this.styleSetDir.root = response.root;
                _this.styleSetDir.scrollToEndButton = response.scrollToEndButton;
                _this.styleSetDir.sendBox = response.sendBox;
                _this.styleSetDir.sendBoxButton = response.sendBoxButton;
                _this.styleSetDir.sendBoxTextArea = response.sendBoxTextArea;
                _this.styleSetDir.sendBoxTextBox = response.sendBoxTextBox;
                _this.styleSetDir.sendStatus = response.sendStatus;
                _this.styleSetDir.singleAttachmentActivity = response.singleAttachmentActivity;
                _this.styleSetDir.spinnerAnnimation = response.spinnerAnnimation;
                _this.styleSetDir.stackedLayout = response.stackedLayout;
                _this.styleSetDir.suggestedAction = response.suggestedAction;
                _this.styleSetDir.suggestedActionsStyleSet = response.suggestedActionsStyleSet;
                _this.styleSetDir.textContent = response.textContent;
                _this.styleSetDir.timestamp = response.timestamp;
                _this.styleSetDir.typingActivity = response.typingActivity;
                _this.styleSetDir.uploadButton = response.uploadButton;
                _this.styleSetDir.videoAttachment = response.videoAttachment;
                _this.styleSetDir.videoContent = response.videoContent;
                _this.styleSetDir.vimeoContent = response.vimeoContent;
                _this.styleSetDir.warningNotification = response.warningNotification;
                _this.styleSetDir.youTubeContent = response.youTubContent;
            }
        }));
        comService.styleOptions$.subscribe((/**
         * @param {?} response
         * @return {?}
         */
        function (response) {
            if (response !== null || response !== undefined) {
                _this.styleOptions = response;
            }
        }));
    }
    /**
     * @param {?} viewChild
     * @return {?}
     */
    BotDirective.prototype.botDirective = /**
     * @param {?} viewChild
     * @return {?}
     */
    function (viewChild) {
        var _this = this;
        this.viewChild = viewChild;
        /** @type {?} */
        var token;
        this.appService.getTokenObs()
            .subscribe((/**
         * @param {?} response
         * @return {?}
         */
        function (response) {
            _this.secretSetting ? token = response.body : token = _this.secret;
            if (response.status == 200 && response.statusText == 'OK' || response == false) {
                /** @type {?} */
                var directLine = window.WebChat.createDirectLine({
                    secret: token,
                    webSocket: false
                });
                if (_this.styleSet && _this.styleOptions) {
                    window.WebChat.renderWebChat({
                        directLine: directLine,
                        userID: "USER_ID",
                        styleOptions: _this.styleOptions,
                        styleSet: _this.styleSet
                    }, _this.viewChild);
                }
                else if (_this.styleSet && !_this.styleOptions) {
                    window.WebChat.renderWebChat({
                        directLine: directLine,
                        userID: "USER_ID",
                        styleSet: _this.styleSet
                    }, _this.viewChild);
                }
                else if (_this.styleOptions && !_this.styleSet) {
                    window.WebChat.renderWebChat({
                        directLine: directLine,
                        userID: "USER_ID",
                        styleOptions: _this.styleOptions,
                    }, _this.viewChild);
                }
                else {
                    window.WebChat.renderWebChat({
                        directLine: directLine,
                        userID: "USER_ID",
                    }, _this.viewChild);
                }
                directLine
                    .postActivity({
                    from: { id: "USER_ID", name: "USER_NAME" },
                    name: "requestWelcomeDialog",
                    type: "event",
                    value: "token"
                })
                    .subscribe((/**
                 * @param {?} id
                 * @return {?}
                 */
                function (id) { return console.log("Posted activity, assigned ID " + id); }), (/**
                 * @param {?} error
                 * @return {?}
                 */
                function (error) { return console.log("Error posting activity " + error); }));
            }
            if (_this.styleSet != null || _this.styleSet != undefined) {
                _this.styleSet.activities = _this.styleSetDir.Activities(_this.styleSet.activities, _this.styleSetDir.activities);
                _this.styleSet.activity = _this.styleSetDir.Activity(_this.styleSet.activity, _this.styleSetDir.activity);
                _this.styleSet.audioAttachment = _this.styleSetDir.AudioAttachment(_this.styleSet.audioAttachment, _this.styleSetDir.audioAttachment);
                _this.styleSet.audioContent = _this.styleSetDir.AudioContent(_this.styleSet.audioContent, _this.styleSetDir.audioContent);
                _this.styleSet.avatar = _this.styleSetDir.Avatar(_this.styleSet.avatar, _this.styleSetDir.avatar);
                _this.styleSet.bubble = _this.styleSetDir.Bubble(_this.styleSet.bubble, _this.styleSetDir.bubble);
                _this.styleSet.carouselFilmStrip = _this.styleSetDir.CarouselFilmStrip(_this.styleSet.carouselFilmStrip, _this.styleSetDir.carouselFilmStrip);
                _this.styleSet.carouselFlipper = _this.styleSetDir.CarouselFlipper(_this.styleSet.carouselFlipper, _this.styleSetDir.carouselFlipper);
                _this.styleSet.connectivityNotification = _this.styleSetDir.ConnectivityNotification(_this.styleSet.connectivityNotification, _this.styleSetDir.connectivityNotification);
                _this.styleSet.dictationInterims = _this.styleSetDir.DictationInterims(_this.styleSet.dictationInterims, _this.styleSetDir.dictationInterims);
                _this.styleSet.downloadAttachment = _this.styleSetDir.DownloadAttachment(_this.styleSet.downloadAttachment, _this.styleSetDir.downloadAttachment);
                _this.styleSet.errorBox = _this.styleSetDir.ErrorBox(_this.styleSet.errorBox, _this.styleSetDir.errorBox);
                _this.styleSet.errorNotification = _this.styleSetDir.ErrorNotification(_this.styleSet.errorNotification, _this.styleSetDir.errorNotification);
                _this.styleSet.microphoneButton = _this.styleSetDir.MicrophoneButton(_this.styleSet.microphoneButton, _this.styleSetDir.microphoneButton);
                _this.styleSet.root = _this.styleSetDir.Root(_this.styleSet.root, _this.styleSetDir.root);
                _this.styleSet.scrollToEndButton = _this.styleSetDir.ScrollToEndButton(_this.styleSet.scrollToEndButton, _this.styleSetDir.scrollToEndButton);
                _this.styleSet.sendBox = _this.styleSetDir.SendBox(_this.styleSet.sendBox, _this.styleSetDir.sendBox);
                _this.styleSet.sendBoxButton = _this.styleSetDir.SendBoxButton(_this.styleSet.sendBoxButton, _this.styleSetDir.sendBoxButton);
                _this.styleSet.sendBoxTextArea = _this.styleSetDir.SendBoxTextArea(_this.styleSet.sendBoxTextArea, _this.styleSetDir.sendBoxTextArea);
                _this.styleSet.sendBoxTextBox = _this.styleSetDir.SendBoxTextBox(_this.styleSet.sendBoxTextBox, _this.styleSetDir.sendBoxTextBox);
                _this.styleSet.sendStatus = _this.styleSetDir.SendStatus(_this.styleSet.sendStatus, _this.styleSetDir.sendStatus);
                _this.styleSet.singleAttachmentActivity = _this.styleSetDir.SingleAttachmentActivity(_this.styleSet.singleAttachmentActivity, _this.styleSetDir.singleAttachmentActivity);
                _this.styleSet.spinnerAnnimation = _this.styleSetDir.SpinnerAnimation(_this.styleSet.spinnerAnnimation, _this.styleSetDir.spinnerAnnimation);
                _this.styleSet.stackedLayout = _this.styleSetDir.StackedLayout(_this.styleSet.stackedLayout, _this.styleSetDir.stackedLayout);
                _this.styleSet.suggestedAction = _this.styleSetDir.SuggestedAction(_this.styleSet.suggestedAction, _this.styleSetDir.suggestedAction);
                _this.styleSet.suggestedActionsStyleSet = _this.styleSetDir.SuggestedActionsStyleSet(_this.styleSet.suggestedActionsStyleSet, _this.styleSetDir.suggestedActionsStyleSet);
                _this.styleSet.textContent = _this.styleSetDir.TextContent(_this.styleSet.textContent, _this.styleSetDir.textContent);
                _this.styleSet.timestamp = _this.styleSetDir.Timestamp(_this.styleSet.timestamp, _this.styleSetDir.timestamp);
                _this.styleSet.typingActivity = _this.styleSetDir.TypingActivity(_this.styleSet.typingActivity, _this.styleSetDir.typingActivity);
                _this.styleSet.typingAnimation = _this.styleSetDir.TypingAnimation(_this.styleSet.typingAnimation, _this.styleSetDir.typingAnimation);
                _this.styleSet.uploadButton = _this.styleSetDir.UploadButton(_this.styleSet.uploadButton, _this.styleSetDir.uploadButton);
                _this.styleSet.videoAttachment = _this.styleSetDir.VideoAttachment(_this.styleSet.videoAttachment, _this.styleSetDir.videoAttachment);
                _this.styleSet.videoContent = _this.styleSetDir.VideoContent(_this.styleSet.videoContent, _this.styleSetDir.videoContent);
                _this.styleSet.vimeoContent = _this.styleSetDir.VimeoContent(_this.styleSet.vimeoContent, _this.styleSetDir.vimeoContent);
                _this.styleSet.warningNotification = _this.styleSetDir.WarningNotification(_this.styleSet.warningNotification, _this.styleSetDir.warningNotification);
                _this.styleSet.youTubeContent = _this.styleSetDir.YouTubeContent(_this.styleSet.youTubeContent, _this.styleSetDir.youTubeContent);
            }
        }));
    };
    /**
     * @return {?}
     */
    BotDirective.prototype.makeError = /**
     * @return {?}
     */
    function () {
        var _this = this;
        this.appService.makeIntentionalError().subscribe(null, (/**
         * @param {?} error
         * @return {?}
         */
        function (error) { return _this.error = error; }));
    };
    BotDirective.decorators = [
        { type: Directive, args: [{
                    selector: 'app-bot',
                    providers: [AppService, ComService]
                },] }
    ];
    /** @nocollapse */
    BotDirective.ctorParameters = function () { return [
        { type: StyleSetDirective },
        { type: HttpClient },
        { type: AppService },
        { type: ComService }
    ]; };
    return BotDirective;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var NgxMicrosoftBotFrameworkModule = /** @class */ (function () {
    function NgxMicrosoftBotFrameworkModule() {
    }
    NgxMicrosoftBotFrameworkModule.decorators = [
        { type: NgModule, args: [{
                    declarations: [
                        BotDirective,
                        StyleSetDirective,
                    ],
                    imports: [
                        BrowserModule,
                        HttpClientModule,
                    ],
                    exports: [],
                    providers: [
                        HttpErrorHandler,
                        MessageService,
                    ]
                },] }
    ];
    return NgxMicrosoftBotFrameworkModule;
}());

export { AppService, BotDirective, ComService, HttpErrorHandler, MessageService, NgxMicrosoftBotFrameworkModule, StyleSetDirective };
//# sourceMappingURL=ngx-microsoft-bot-framework.js.map
